@@ -92,6 +92,9 @@ else:
     )
 
 
+IS_PYTHONW = sys.executable and sys.executable.endswith("pythonw.exe")
+
+
 def catch_config_error(method):
     """Method decorator for catching invalid config (Trait/ArgumentErrors) during init.
 
@@ -143,21 +146,21 @@ class Application(SingletonConfigurable):
 
     # The name of the application, will usually match the name of the command
     # line application
-    name = Unicode("application")
+    name: t.Union[str, Unicode] = Unicode("application")
 
     # The description of the application that is printed at the beginning
     # of the help.
-    description = Unicode("This is an application.")
+    description: t.Union[str, Unicode] = Unicode("This is an application.")
     # default section descriptions
-    option_description = Unicode(option_description)
-    keyvalue_description = Unicode(keyvalue_description)
-    subcommand_description = Unicode(subcommand_description)
+    option_description: t.Union[str, Unicode] = Unicode(option_description)
+    keyvalue_description: t.Union[str, Unicode] = Unicode(keyvalue_description)
+    subcommand_description: t.Union[str, Unicode] = Unicode(subcommand_description)
 
     python_config_loader_class = PyFileConfigLoader
     json_config_loader_class = JSONFileConfigLoader
 
     # The usage and example string that goes at the end of the help string.
-    examples = Unicode()
+    examples: t.Union[str, Unicode] = Unicode()
 
     # A sequence of Configurable subclasses whose config=True attributes will
     # be exposed at the command line.
@@ -184,16 +187,18 @@ class Application(SingletonConfigurable):
                     yield parent
 
     # The version string of this application.
-    version = Unicode("0.0")
+    version: t.Union[str, Unicode] = Unicode("0.0")
 
     # the argv used to initialize the application
-    argv = List()
+    argv: t.Union[t.List[str], List] = List()
 
     # Whether failing to load config files should prevent startup
-    raise_config_file_errors = Bool(TRAITLETS_APPLICATION_RAISE_CONFIG_FILE_ERROR)
+    raise_config_file_errors: t.Union[bool, Bool] = Bool(
+        TRAITLETS_APPLICATION_RAISE_CONFIG_FILE_ERROR
+    )
 
     # The log level for the application
-    log_level = Enum(
+    log_level: t.Union[str, int, Enum] = Enum(
         (0, 10, 20, 30, 40, 50, "DEBUG", "INFO", "WARN", "ERROR", "CRITICAL"),
         default_value=logging.WARN,
         help="Set the log level by value or name.",
@@ -201,11 +206,11 @@ class Application(SingletonConfigurable):
 
     _log_formatter_cls = LevelFormatter
 
-    log_datefmt = Unicode(
+    log_datefmt: t.Union[str, Unicode] = Unicode(
         "%Y-%m-%d %H:%M:%S", help="The date format used by logging formatters for %(asctime)s"
     ).tag(config=True)
 
-    log_format = Unicode(
+    log_format: t.Union[str, Unicode] = Unicode(
         "[%(name)s]%(highlevel)s %(message)s",
         help="The Logging format template",
     ).tag(config=True)
@@ -252,11 +257,12 @@ class Application(SingletonConfigurable):
             "disable_existing_loggers": False,
         }
 
-        if sys.executable and sys.executable.endswith("pythonw.exe"):
+        if IS_PYTHONW:
             # disable logging
             # (this should really go to a file, but file-logging is only
             # hooked up in parallel applications)
-            del config["handlers"]["loggers"]
+            del config["handlers"]
+            del config["loggers"]
 
         return config
 
@@ -276,6 +282,8 @@ class Application(SingletonConfigurable):
         config = self.get_default_logging_config()
         nested_update(config, self.logging_config or {})
         dictConfig(config)
+        # make a note that we have configured logging
+        self._logging_configured = True
 
     @default("log")
     def _log_default(self):
@@ -321,7 +329,7 @@ class Application(SingletonConfigurable):
 
             .. code-block:: python
 
-               c.Application.logging_configuration = {
+               c.Application.logging_config = {
                    'handlers': {
                        'file': {
                            'class': 'logging.FileHandler',
@@ -345,7 +353,7 @@ class Application(SingletonConfigurable):
     #: the alias map for configurables
     #: Keys might strings or tuples for additional options; single-letter alias accessed like `-v`.
     #: Values might be like "Class.trait" strings of two-tuples: (Class.trait, help-text).
-    aliases: t.Dict[str, str] = {"log-level": "Application.log_level"}
+    aliases: t.Dict[str, t.Any] = {"log-level": "Application.log_level"}
 
     # flags for loading Configurables or store_const style flags
     # flags are loaded from this dict by '--key' flags
@@ -383,12 +391,12 @@ class Application(SingletonConfigurable):
     # this must be a dict of two-tuples,
     # the first element being the application class/import string
     # and the second being the help string for the subcommand
-    subcommands = Dict()
+    subcommands: t.Union[t.Dict[str, t.Tuple[str, str]], Dict] = Dict()
     # parse_command_line will initialize a subapp, if requested
     subapp = Instance("traitlets.config.application.Application", allow_none=True)
 
     # extra command-line arguments that don't set config values
-    extra_args = List(Unicode())
+    extra_args: t.Union[t.List[str], List] = List(Unicode())
 
     cli_config = Instance(
         Config,
@@ -403,11 +411,11 @@ class Application(SingletonConfigurable):
 
     _loaded_config_files = List()
 
-    show_config = Bool(
+    show_config: t.Union[bool, Bool] = Bool(
         help="Instead of starting the Application, dump configuration to stdout"
     ).tag(config=True)
 
-    show_config_json = Bool(
+    show_config_json: t.Union[bool, Bool] = Bool(
         help="Instead of starting the Application, dump configuration to stdout (as JSON)"
     ).tag(config=True)
 
@@ -684,7 +692,9 @@ class Application(SingletonConfigurable):
     @catch_config_error
     def initialize_subcommand(self, subc, argv=None):
         """Initialize a subcommand with argv."""
-        subapp, _ = self.subcommands.get(subc)
+        val = self.subcommands.get(subc)
+        assert val is not None
+        subapp, _ = val
 
         if isinstance(subapp, str):
             subapp = import_item(subapp)
@@ -731,7 +741,7 @@ class Application(SingletonConfigurable):
         for alias, longname in self.aliases.items():
             if isinstance(longname, tuple):
                 longname, _ = longname
-            cls, trait = longname.split(".", 1)  # type:ignore[assignment]
+            cls, trait = longname.split(".", 1)
             children = mro_tree[cls]  # type:ignore[index]
             if len(children) == 1:
                 # exactly one descendent, promote alias
@@ -824,12 +834,12 @@ class Application(SingletonConfigurable):
 
         if not isinstance(path, list):
             path = [path]
-        for path in path[::-1]:
+        for current in reversed(path):
             # path list is in descending priority order, so load files backwards:
-            pyloader = cls.python_config_loader_class(basefilename + ".py", path=path, log=log)
+            pyloader = cls.python_config_loader_class(basefilename + ".py", path=current, log=log)
             if log:
-                log.debug("Looking for %s in %s", basefilename, path or os.getcwd())
-            jsonloader = cls.json_config_loader_class(basefilename + ".json", path=path, log=log)
+                log.debug("Looking for %s in %s", basefilename, current or os.getcwd())
+            jsonloader = cls.json_config_loader_class(basefilename + ".json", path=current, log=log)
             loaded: t.List[t.Any] = []
             filenames: t.List[str] = []
             for loader in [pyloader, jsonloader]:
@@ -876,7 +886,7 @@ class Application(SingletonConfigurable):
         """Load config files by filename and path."""
         filename, ext = os.path.splitext(filename)
         new_config = Config()
-        for (config, filename) in self._load_config_files(
+        for (config, fname) in self._load_config_files(
             filename,
             path=path,
             log=self.log,
@@ -884,9 +894,9 @@ class Application(SingletonConfigurable):
         ):
             new_config.merge(config)
             if (
-                filename not in self._loaded_config_files
+                fname not in self._loaded_config_files
             ):  # only add to list of loaded files if not previously loaded
-                self._loaded_config_files.append(filename)
+                self._loaded_config_files.append(fname)
         # add self.cli_config to preserve CLI config priority
         new_config.merge(self.cli_config)
         self.update_config(new_config)
@@ -935,6 +945,8 @@ class Application(SingletonConfigurable):
         """generate default config file from Configurables"""
         lines = ["# Configuration file for %s." % self.name]
         lines.append("")
+        lines.append("c = get_config()  # noqa")
+        lines.append("")
         classes = self.classes if classes is None else classes
         config_classes = list(self._classes_with_config_traits(classes))
         for cls in config_classes:
@@ -942,9 +954,14 @@ class Application(SingletonConfigurable):
         return "\n".join(lines)
 
     def close_handlers(self):
-        for handler in self.log.handlers:
-            with suppress(Exception):
-                handler.close()
+        if getattr(self, "_logging_configured", False):
+            # don't attempt to close handlers unless they have been opened
+            # (note accessing self.log.handlers will create handlers if they
+            # have not yet been initialised)
+            for handler in self.log.handlers:
+                with suppress(Exception):
+                    handler.close()
+            self._logging_configured = False
 
     def exit(self, exit_status=0):
         self.log.debug("Exiting application: %s" % self.name)
